## Getting started

We recommend you simply jump in and explore. Look at the pre-run simulations, the evolution of life history traits over time. Afterwards, browse parameters, modify them and observe how they affect the evolution of life history.
To understand the tool more deeply, consider browsing the ODD (Overview, Design concepts, Details) protocol. It will provide the model designer's view – broader context, list of entities, processes and design concepts.

You can also run AEGIS locally. Install in python in terminal using `pip install aegis-sim` and run the GUI using `python3 -m aegis` command. You can also run simulations from terminal; more information is available on our [Github page](https://github.com/valenzano-lab/aegis).
